# tangled-game-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.8.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import tangled_game_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import tangled_game_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import tangled_game_client
from tangled_game_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = tangled_game_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with tangled_game_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = tangled_game_client.DefaultApi(api_client)
    create_game_request = tangled_game_client.CreateGameRequest() # CreateGameRequest | 

    try:
        # Create a new game
        api_response = api_instance.create_game(create_game_request)
        print("The response of DefaultApi->create_game:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->create_game: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**create_game**](docs/DefaultApi.md#create_game) | **POST** /create_game | Create a new game
*DefaultApi* | [**get_game_state**](docs/DefaultApi.md#get_game_state) | **GET** /game_state | Get the state of the game
*DefaultApi* | [**get_legal_moves**](docs/DefaultApi.md#get_legal_moves) | **GET** /legal_moves | Get the legal moves for the current game state
*DefaultApi* | [**get_score**](docs/DefaultApi.md#get_score) | **GET** /get_score | Get the score of the game
*DefaultApi* | [**get_scorers**](docs/DefaultApi.md#get_scorers) | **GET** /get_scorers | Get the list of available scoring algorithms
*DefaultApi* | [**join_game**](docs/DefaultApi.md#join_game) | **POST** /join_game | Connect client to a game and get player token
*DefaultApi* | [**make_move**](docs/DefaultApi.md#make_move) | **POST** /move | Make a move in the game
*DefaultApi* | [**public_create_game**](docs/DefaultApi.md#public_create_game) | **POST** /public/create_game | Create a new game (public)
*DefaultApi* | [**public_get_game_state**](docs/DefaultApi.md#public_get_game_state) | **GET** /public/game_state | Get the state of the game (public)
*DefaultApi* | [**public_get_legal_moves**](docs/DefaultApi.md#public_get_legal_moves) | **GET** /public/legal_moves | Get the legal moves for the current game state (public)
*DefaultApi* | [**public_get_score**](docs/DefaultApi.md#public_get_score) | **GET** /public/get_score | Get the score of the game (public)
*DefaultApi* | [**public_get_scorers**](docs/DefaultApi.md#public_get_scorers) | **GET** /public/get_scorers | Get the list of available scoring algorithms (public)
*DefaultApi* | [**public_join_game**](docs/DefaultApi.md#public_join_game) | **POST** /public/join_game | Connect client to a game and get player token (public)
*DefaultApi* | [**public_make_move**](docs/DefaultApi.md#public_make_move) | **POST** /public/move | Make a move in the game (public)
*DefaultApi* | [**public_secret_create_game**](docs/DefaultApi.md#public_secret_create_game) | **POST** /public/secret_create_game | 


## Documentation For Models

 - [CreateGame200Response](docs/CreateGame200Response.md)
 - [CreateGameRequest](docs/CreateGameRequest.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [GetGameState200Response](docs/GetGameState200Response.md)
 - [GetGameState200ResponseState](docs/GetGameState200ResponseState.md)
 - [GetLegalMoves200Response](docs/GetLegalMoves200Response.md)
 - [GetScore200Response](docs/GetScore200Response.md)
 - [GetScore200ResponseScore](docs/GetScore200ResponseScore.md)
 - [GetScorers200Response](docs/GetScorers200Response.md)
 - [JoinGame200Response](docs/JoinGame200Response.md)
 - [JoinGameRequest](docs/JoinGameRequest.md)
 - [MakeMove200Response](docs/MakeMove200Response.md)
 - [MakeMove403Response](docs/MakeMove403Response.md)
 - [MakeMoveRequest](docs/MakeMoveRequest.md)
 - [PublicSecretCreateGame200Response](docs/PublicSecretCreateGame200Response.md)
 - [PublicSecretCreateGameRequest](docs/PublicSecretCreateGameRequest.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="auth0"></a>
### auth0

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://snowdropquantum.ca.auth0.com/authorize
- **Scopes**: 
 - **read**: Grants read access
 - **write**: Grants write access
 - **delete**: Grants delete access


## Author




